#[non_exhaustive]pub enum SelectorOperator {
In,
NotIn,
Exists,
DoesNotExist,
}Expand description
Set-based operator for super::SelectorRequirement.
| Operator | Values | Match |
|---|---|---|
In | non-empty | key exists and value is in values |
NotIn | non-empty | key is absent or value is not in values |
Exists | empty | key exists |
DoesNotExist | empty | key is absent |
Example
use solti_model::SelectorOperator;
assert_eq!(SelectorOperator::DoesNotExist.to_string(), "DoesNotExist");Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
In
Label value must be one of values.
NotIn
Label is absent or its value is not in values.
Exists
Label key must exist.
DoesNotExist
Label key must not exist.