pub struct Annotations(/* private fields */);Expand description
Key-sorted, free-form resource metadata.
Annotations are kept distinct from labels because they are descriptive data, not selectors used for routing or filtering.
Implementations
Sourceimpl Annotations
impl Annotations
Sourcepub fn insert<K, V>(&mut self, key: K, value: V) -> &mut Self
pub fn insert<K, V>(&mut self, key: K, value: V) -> &mut Self
Inserts or replaces an annotation.
Sourcepub fn iter(&self) -> impl Iterator<Item = (&str, &str)>
pub fn iter(&self) -> impl Iterator<Item = (&str, &str)>
Iterates over annotations in key order.
Sourcepub fn validate(&self) -> ModelResult<()>
pub fn validate(&self) -> ModelResult<()>
Validates annotation keys and total size.
Annotation values remain arbitrary UTF-8 strings.
Errors
Returns ModelError::Invalid for an invalid key or when key and value bytes exceed 256 KiB in total.