pub struct RunnerCapability { /* private fields */ }Expand description
One registered runner and the workload GVKs it can execute.
Labels are the same static labels used by runnerSelector.
Implementations
Sourceimpl RunnerCapability
impl RunnerCapability
Sourcepub fn new(
name: impl Into<String>,
labels: Labels,
workload_types: Vec<WorkloadTypeMeta>,
) -> ModelResult<Self>
pub fn new( name: impl Into<String>, labels: Labels, workload_types: Vec<WorkloadTypeMeta>, ) -> ModelResult<Self>
Creates a registered runner capability.
Workload types are stored in canonical GVK order.
Errors
Returns ModelError::Invalid when the name or labels are invalid, no workload is declared, a GVK is duplicated, or Embedded is declared.
Sourcepub fn workload_types(&self) -> &[WorkloadTypeMeta]
pub fn workload_types(&self) -> &[WorkloadTypeMeta]
Canonically ordered workload GVKs handled by the runner.