pub struct TaskManifestMeta { /* private fields */ }Expand description
User-owned metadata accepted in a TaskManifest.
Runtime identity, resource version, generation, creation time and status are deliberately absent because the state store owns them.
Implementations
Sourceimpl TaskManifestMeta
impl TaskManifestMeta
Sourcepub fn new(name: impl AsRef<str>) -> ModelResult<Self>
pub fn new(name: impl AsRef<str>) -> ModelResult<Self>
Sourcepub fn annotations(&self) -> &Annotations
pub fn annotations(&self) -> &Annotations
Free-form metadata.