pub struct Timeout(/* private fields */);Expand description
Timeout value in milliseconds.
use solti_model::Timeout;
let timeout = Timeout::new(5_000).unwrap();
assert_eq!(timeout.as_millis(), 5_000);
let timeout = Timeout::new(10_000).unwrap();
assert_eq!(format!("{timeout}"), "10000ms");Implementations
Sourceimpl Timeout
impl Timeout
Sourcepub fn new(ms: u64) -> ModelResult<Self>
pub fn new(ms: u64) -> ModelResult<Self>
Creates a timeout value.
Errors
Returns ModelError::Invalid when ms is zero.
Example
use solti_model::Timeout;
let timeout = Timeout::new(5_000).unwrap();
assert_eq!(timeout.as_millis(), 5_000);Trait Implementations
impl Copy for Timeout
Sourceimpl<'de> Deserialize<'de> for Timeout
impl<'de> Deserialize<'de> for Timeout
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Timeout
Sourceimpl JsonSchema for Timeout
impl JsonSchema for Timeout
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for Timeout
impl Ord for Timeout
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Timeout
impl PartialOrd for Timeout
impl StructuralPartialEq for Timeout